Crate zink_abi_macro
zink_
abi_
macro
0.1.12
All Items
Crate Items
Macros
Crate
zink_
abi_
macro
Macros

import
The
import!
macro generates a Rust struct and implementation for interacting with an Ethereum smart contract based on its ABI (Application Binary Interface) and deploys the corresponding contract.